pub struct Pointer {
pub oid: [u8; 32],
pub size: u64,
pub extensions: Vec<(String, String)>,
}Expand description
A parsed LFS pointer. Represents the content of a git blob that stands in for a real binary file.
Fields
oid: [u8; 32]sha256 of the real file content.
size: u64Size of the real file, in bytes.
extensions: Vec<(String, String)>Unknown keys preserved for forward compatibility. Round-tripped on write. Keys are stored lowercase; values as-parsed.
Implementations
Sourceimpl Pointer
impl Pointer
Sourcepub fn parse(bytes: &[u8]) -> Result<Self, ParseError>
pub fn parse(bytes: &[u8]) -> Result<Self, ParseError>
Parse an LFS pointer from canonical pointer bytes.
Errors
Returns a ParseError if the bytes are too large, non-ASCII, use
unsupported line endings, or do not contain a valid version, oid, and
size.
pub fn oid_hex(&self) -> String